@@ -26,9 +26,5 @@ void		ve_entry_set_red (GtkWidget *w,
 
 GtkWidget *	ve_gtk_option_menu_get_item (GtkOptionMenu *option_menu,
 					     int index);
-int		ve_gtk_option_menu_get_history (GtkOptionMenu *option_menu);
-
-/* from gnome-libs, not to require new gnome-libs */
-void		ve_gnome_dialog_grab_focus (GnomeDialog *dialog, gint button);
 
 #endif /* VE_MISCUI_H */
